# swagger-client
null

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 0.90
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import swagger_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import swagger_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    api_instance.v1_actions_action_uid_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_actions_action_uid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get the status of all currently executing, pending or completed actions on all entities (cluster, nodes and bdbs). This API is used to track every long-lived API request which returns either a task_id or an action_uid.
    api_instance.v1_actions_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_actions_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get all alert states for all bdbs.
    api_instance.v1_bdbs_alerts_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_alerts_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the database
alert = 'alert_example' # str | The alert name

try:
    # Get bdb alert state.
    api_instance.v1_bdbs_alerts_intuid_alert_get(uid, alert)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_alerts_intuid_alert_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get all alert states for bdb.
    api_instance.v1_bdbs_alerts_intuid_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_alerts_intuid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 1.2 # float | The database ID

try:
    # Updates database’s one or many alerts configuration
    api_instance.v1_bdbs_alerts_intuid_post(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_alerts_intuid_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
bdb_uid = 'bdb_uid_example' # str | The unique ID of the local CRDB instance.
interval = 'interval_example' # str | Optional time interval for which we want stats: 1sec/10sec/5min/15min/1hour/12hour/1week (optional)
stime = 'stime_example' # str | Optional start time from which we want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)
etime = 'etime_example' # str | Optional end time after which we don’t want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)

try:
    # Get stats for a all peer instances of a local CRDB instance.
    api_instance.v1_bdbs_bdb_uid_peer_stats_get(bdb_uid, interval=interval, stime=stime, etime=etime)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_bdb_uid_peer_stats_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
bdb_uid = 'bdb_uid_example' # str | The unique ID of the local CRDB instance.
uid = 'uid_example' # str | The peer instance uid, as specified in the CRDB instance list.
interval = 'interval_example' # str | Optional time interval for which we want stats: 1sec/10sec/5min/15min/1hour/12hour/1week (optional)
stime = 'stime_example' # str | Optional start time from which we want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)
etime = 'etime_example' # str | Optional end time after which we don’t want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)

try:
    # Get stats for a specific CRDB peer instance.
    api_instance.v1_bdbs_bdb_uid_peer_stats_intuid_get(bdb_uid, uid, interval=interval, stime=stime, etime=etime)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_bdb_uid_peer_stats_intuid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
bdb_uid = 'bdb_uid_example' # str | The unique ID of the local database.
interval = 'interval_example' # str | Optional time interval for which we want stats: 1sec/10sec/5min/15min/1hour/12hour/1week (optional)
stime = 'stime_example' # str | Optional start time from which we want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)
etime = 'etime_example' # str | Optional end time after which we don’t want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)

try:
    # Get stats for a all syncer sources of a local database.
    api_instance.v1_bdbs_bdb_uid_sync_source_stats_get(bdb_uid, interval=interval, stime=stime, etime=etime)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_bdb_uid_sync_source_stats_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
bdb_uid = 'bdb_uid_example' # str | The unique ID of the local database.
uid = 'uid_example' # str | The sync_source uid.
interval = 'interval_example' # str | Optional time interval for which we want stats: 1sec/10sec/5min/15min/1hour/12hour/1week (optional)
stime = 'stime_example' # str | Optional start time from which we want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)
etime = 'etime_example' # str | Optional end time after which we don’t want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)

try:
    # Get stats for a specific syncer (replica-of) instance.
    api_instance.v1_bdbs_bdb_uid_sync_source_stats_intuid_get(bdb_uid, uid, interval=interval, stime=stime, etime=etime)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_bdb_uid_sync_source_stats_intuid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get all alert states for all crdt sources of all CRDBs.
    api_instance.v1_bdbs_crdt_sources_alerts_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_crdt_sources_alerts_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the database

try:
    # Get all alert states for all crdt source for specific local bdb of CRDB.
    api_instance.v1_bdbs_crdt_sources_alerts_intuid_get(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_crdt_sources_alerts_intuid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the database
crdt_src_id = 'crdt_src_id_example' # str | The ID of the crdt source in this BDB
alert = 'alert_example' # str | The alert name

try:
    # Get bdb alert state.
    api_instance.v1_bdbs_crdt_sources_alerts_intuid_intcrdt_src_id_alert_get(uid, crdt_src_id, alert)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_crdt_sources_alerts_intuid_intcrdt_src_id_alert_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the database
crdt_src_id = 'crdt_src_id_example' # str | The ID of the crdt source in this BDB

try:
    # Get all alert states for specific crdt source for specific local bdb of CRDB.
    api_instance.v1_bdbs_crdt_sources_alerts_intuid_intcrdt_src_id_get(uid, crdt_src_id)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_crdt_sources_alerts_intuid_intcrdt_src_id_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
fields = 'fields_example' # str | Optional comma separated list of field names to return (by default all fields are returned). (optional)

try:
    # Get all databases in the cluster.
    api_instance.v1_bdbs_get(fields=fields)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the database

try:
    # Reset database current backup status (backup_status) to idle if not in progress. As well clear exiting backup_failure_reason if exits
    api_instance.v1_bdbs_intuid_actions_backup_reset_status_put(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_intuid_actions_backup_reset_status_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the database

try:
    # Initiate a database export.
    api_instance.v1_bdbs_intuid_actions_export_post(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_intuid_actions_export_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the database

try:
    # Reset database current export status (export_status) to idle if not in progress. As well clear exiting export_failure_reason if exits
    api_instance.v1_bdbs_intuid_actions_export_reset_status_put(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_intuid_actions_export_reset_status_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the database

try:
    # Initiate a manual import process.
    api_instance.v1_bdbs_intuid_actions_import_post(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_intuid_actions_import_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the database

try:
    # Reset database current import status (import_status) to idle if not in progress. As well clear exiting import_failure_reason if exits
    api_instance.v1_bdbs_intuid_actions_import_reset_status_put(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_intuid_actions_import_reset_status_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get optimized shards placement for the given database.
    api_instance.v1_bdbs_intuid_actions_optimize_shards_placement_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_intuid_actions_optimize_shards_placement_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the database for which recovery plan is required.

try:
    # Fetch the recovery plan for a database. The recovery plan provides information about the recovery status (if it is possible) and specific detail on which available files to recovery from have been found.
    api_instance.v1_bdbs_intuid_actions_recover_get(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_intuid_actions_recover_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the database to recover.

try:
    # Initiate recovery for a database in recovery state.
    api_instance.v1_bdbs_intuid_actions_recover_post(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_intuid_actions_recover_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the database for which update is requested.
action = 'action_example' # str | Additional action to perform. Currently the supported actions are: flush , reset_admin_pass .

try:
    # Update the configuration of an active database.
    api_instance.v1_bdbs_intuid_anyaction_put(uid, action)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_intuid_anyaction_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 1.2 # float | The uid of the db on which the command will be performed.

try:
    # Execute a redis/memcached command, per the db type.
    api_instance.v1_bdbs_intuid_command_post(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_intuid_command_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the database to delete.

try:
    # Delete an active database.
    api_instance.v1_bdbs_intuid_delete(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_intuid_delete: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 1.2 # float | The unique ID of the database requested.
fields = 'fields_example' # str | Optional comma separated list of field names to return (by default all fields are returned). (optional)

try:
    # Get single database (bdb object) as json.
    api_instance.v1_bdbs_intuid_get(uid, fields=fields)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_intuid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the database to which the password is to be added.

try:
    # Delete a password from the bdb’s default user (i.e., for AUTH <password> authentications).
    api_instance.v1_bdbs_intuid_passwords_delete(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_intuid_passwords_delete: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the database to which the password is to be added.

try:
    # Add a password to the bdb’s default user (i.e., for AUTH <password> authentications).
    api_instance.v1_bdbs_intuid_passwords_post(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_intuid_passwords_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the database to which the password is to be added.

try:
    # Set a (single) password to the bdb’s default user (i.e., for AUTH <password> authentications).
    api_instance.v1_bdbs_intuid_passwords_put(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_intuid_passwords_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the database for which update is requested.

try:
    # Update the configuration of an active database.  This is the simplified version of the update request which contains no additional action.
    api_instance.v1_bdbs_intuid_put(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_intuid_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Upgrade a BDB
    api_instance.v1_bdbs_intuid_upgrade_post()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_intuid_upgrade_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Create a new database in the cluster.
    api_instance.v1_bdbs_post()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get all alert states for all replica sources of all BDBs.
    api_instance.v1_bdbs_replica_sources_alerts_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_replica_sources_alerts_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the database

try:
    # Get all alert states for all replica source of specific bdb.
    api_instance.v1_bdbs_replica_sources_alerts_intuid_get(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_replica_sources_alerts_intuid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the database
replica_src_id = 'replica_src_id_example' # str | The ID of the replica source in this BDB
alert = 'alert_example' # str | The alert name

try:
    # Get replica source alert state of specific bdb.
    api_instance.v1_bdbs_replica_sources_alerts_intuid_intreplica_src_id_alert_get(uid, replica_src_id, alert)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_replica_sources_alerts_intuid_intreplica_src_id_alert_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the database
replica_src_id = 'replica_src_id_example' # str | The ID of the replica source in this BDB

try:
    # Get all alert states for specific replica source of bdb.
    api_instance.v1_bdbs_replica_sources_alerts_intuid_intreplica_src_id_get(uid, replica_src_id)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_replica_sources_alerts_intuid_intreplica_src_id_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
interval = 'interval_example' # str | Optional time interval for for which we want stats: 1sec/10sec/5min/15min/1hour/12hour/1week (optional)
stime = 'stime_example' # str | Optional start time from which we want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)
etime = 'etime_example' # str | Optional end time after which we don’t want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)

try:
    # Get stats for all BDBs.
    api_instance.v1_bdbs_stats_get(interval=interval, stime=stime, etime=etime)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_stats_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the BDB requested.
interval = 'interval_example' # str | Optional time interval for for which we want stats: 1sec/10sec/5min/15min/1hour/12hour/1week (optional)
stime = 'stime_example' # str | Optional start time from which we want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)
etime = 'etime_example' # str | Optional end time after which we don’t want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)

try:
    # Get stats for BDB.
    api_instance.v1_bdbs_stats_intuid_get(uid, interval=interval, stime=stime, etime=etime)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_stats_intuid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
metrics = 'metrics_example' # str | Optional comma separated list of metric names for which we want statistics (default is all). (optional)

try:
    # Get the most recent statistic information for all BDBs.
    api_instance.v1_bdbs_stats_last_get(metrics=metrics)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_stats_last_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the requested BDB.
metrics = 'metrics_example' # str | Optional comma separated list of metric names for which we want statistics (default is all). (optional)

try:
    # Get the most recent statistic information for BDB.
    api_instance.v1_bdbs_stats_last_intuid_get(uid, metrics=metrics)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_stats_last_intuid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    api_instance.v1_bdbs_stringuid_modules_config_post()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_stringuid_modules_config_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    api_instance.v1_bdbs_stringuid_modules_upgrade_post()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bdbs_stringuid_modules_upgrade_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Initiate bootstrapping.
    api_instance.v1_bootstrap_action_post()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bootstrap_action_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get the local node’s bootstrap status.
    api_instance.v1_bootstrap_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bootstrap_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Perform bootstrap validation.
    api_instance.v1_bootstrap_validate_action_post()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_bootstrap_validate_action_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
action = 'action_example' # str | The name of the action to cancel, currently no actions are supported.

try:
    # Cancel a queued or executing cluster action, or remove the status of a previously executed and completed action.
    api_instance.v1_cluster_actions_action_delete(action)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_actions_action_delete: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    api_instance.v1_cluster_actions_action_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_actions_action_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
action = 'action_example' # str | The name of the action required.

try:
    # Initiate a cluster-wide action.
    api_instance.v1_cluster_actions_action_post(action)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_actions_action_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
action = 'action_example' # str | The action to check.

try:
    # Get the status of a currently executing, queued or completed cluster action.
    api_instance.v1_cluster_actions_get(action)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_actions_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
ignore_settings = 'ignore_settings_example' # str | Optional retrieve updated alert state regardless if alert is enabled in cluster’s alert_settings. When not present a disabled alert will always be retrieved as disabled with a false state. (optional)

try:
    # Get cluster alert state.
    api_instance.v1_cluster_alerts_alert_get(ignore_settings=ignore_settings)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_alerts_alert_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
ignore_settings = 'ignore_settings_example' # str | Optional retrieve updated alert state regardless if alert is enabled in cluster’s alert_settings. When not present a disabled alert will always be retrieved as disabled with a false state. (optional)

try:
    # Get all alert states for the cluster object.
    api_instance.v1_cluster_alerts_get(ignore_settings=ignore_settings)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_alerts_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Delete the Database Connections Auditing configurations.
    api_instance.v1_cluster_auditing_db_conns_delete()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_auditing_db_conns_delete: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get the Database Connections Auditing configuration, as JSON.
    api_instance.v1_cluster_auditing_db_conns_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_auditing_db_conns_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Update the Database Connections Auditing configurations.
    api_instance.v1_cluster_auditing_db_conns_put()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_auditing_db_conns_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get the clusters certificates.
    api_instance.v1_cluster_certificates_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_certificates_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Regenerates all internal cluster certificates. the certificate rotation will be performed on all nodes within the cluster. If “name” is provided, rotate only the specified certificate on all nodes within the cluster.
    api_instance.v1_cluster_certificates_rotate_post()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_certificates_rotate_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Removes specified cluster certificate both from CCS and from disk across all nodes. Only optional certificates can be deleted through this endpoint.
    api_instance.v1_cluster_certificates_stringcertificate_name_delete()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_certificates_stringcertificate_name_delete: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get cluster-wide fs wd config.
    api_instance.v1_cluster_fs_wd_config_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_fs_wd_config_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Set cluster-wide fs wd config.
    api_instance.v1_cluster_fs_wd_config_put()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_fs_wd_config_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get fs wd path config for cluster.
    api_instance.v1_cluster_fs_wd_fs_path_config_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_fs_wd_fs_path_config_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Set fs wd path config for cluster.
    api_instance.v1_cluster_fs_wd_fs_path_config_put()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_fs_wd_fs_path_config_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get cluster info.
    api_instance.v1_cluster_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Clear the LDAP configuration.
    api_instance.v1_cluster_ldap_delete()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_ldap_delete: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get the LDAP configuration, as JSON.
    api_instance.v1_cluster_ldap_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_ldap_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Set or update cluster LDAP configuration.
    api_instance.v1_cluster_ldap_put()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_ldap_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # List possible redis module capabilities Example request:
    api_instance.v1_cluster_module_capabilities_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_module_capabilities_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Update cluster settings.
    api_instance.v1_cluster_put()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get cluster services settings.
    api_instance.v1_cluster_services_configuration_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_services_configuration_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Update the cluster services settings.
    api_instance.v1_cluster_services_configuration_put()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_services_configuration_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
interval = 'interval_example' # str | Optional time interval for which we want stats: 1sec/10sec/5min/15min/1hour/12hour/1week (optional)
stime = 'stime_example' # str | Optional start time from which we want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format. (optional)
etime = 'etime_example' # str | Optional end time after which we don’t want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)

try:
    # Get cluster stats.
    api_instance.v1_cluster_stats_get(interval=interval, stime=stime, etime=etime)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_stats_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
interval = 'interval_example' # str | Optional time interval for which we want stats: 1sec/10sec/5min/15min/1hour/12hour/1week. Default: 1sec. (optional)
stime = 'stime_example' # str | Optional start time from which we want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)
etime = 'etime_example' # str | Optional end time after which we don’t want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)

try:
    # Get the last cluster stat.
    api_instance.v1_cluster_stats_last_get(interval=interval, stime=stime, etime=etime)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_stats_last_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Replaces specified cluster certificate with given one, the new certificate will be replaced on all nodes within the cluster. This end point will make sure given certificate is valid before actually updating the cluster.
    api_instance.v1_cluster_update_cert_put()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_cluster_update_cert_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Fetch debuginfo from all nodes that are relevent to given bdb uid.
    api_instance.v1_debuginfo_all_bdb_intbdb_uid_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_debuginfo_all_bdb_intbdb_uid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Fetch debuginfo from all nodes.
    api_instance.v1_debuginfo_all_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_debuginfo_all_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Fetch debuginfo tarfile which contains logs and other system information used for troubleshooting, for the given bdb.
    api_instance.v1_debuginfo_node_bdb_intbdb_uid_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_debuginfo_node_bdb_intbdb_uid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Fetch debuginfo tarfile which contains logs and other system information used for troubleshooting.
    api_instance.v1_debuginfo_node_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_debuginfo_node_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
interval = 'interval_example' # str | Optional time interval for which we want stats: 1sec/10sec/5min/15min/1hour/12hour/1week (optional)
stime = 'stime_example' # str | Optional start time from which we want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)
etime = 'etime_example' # str | Optional end time after which we don’t want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)

try:
    # Get stats for all endpoint-proxy links. Note: this method will return both endpoints and listeners stats for backwards compatability.
    api_instance.v1_endpoints_stats_get(interval=interval, stime=stime, etime=etime)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_endpoints_stats_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
object = 'object_example' # str | Optional. The RLEC object name: ‘cluster’, ‘node’, ‘bdb’ etc. (optional)

try:
    # Get the jsonschema of RLEC objects.
    api_instance.v1_jsonschema_get(object=object)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_jsonschema_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get all ldap_mapping objects.
    api_instance.v1_ldap_mappings_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_ldap_mappings_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The ldap_mapping unique ID.

try:
    # Delete an LDAP mapping object.
    api_instance.v1_ldap_mappings_intuid_delete(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_ldap_mappings_intuid_delete: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The object’s unique ID.

try:
    # Get a single ldap_mapping object.
    api_instance.v1_ldap_mappings_intuid_get(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_ldap_mappings_intuid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Update an existing ldap_mapping object.
    api_instance.v1_ldap_mappings_intuid_put()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_ldap_mappings_intuid_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Create a new LDAP mapping.
    api_instance.v1_ldap_mappings_post()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_ldap_mappings_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Returns the license details, including license string, expiration, and supported features.
    api_instance.v1_license_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_license_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Install a new license string.
    api_instance.v1_license_put()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_license_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
stime = 'stime_example' # str | Optional start time before which we don’t want events. (optional)
etime = 'etime_example' # str | Optional end time after which we don’t want events. (optional)
order = 'order_example' # str | Desc/asc - get events in descending or ascending order. Defaults to asc. (optional)
limit = 'limit_example' # str | Optional maximum number of events to return. (optional)
offset = 'offset_example' # str | Optional. Skip offset events before returning first one (useful for pagination). (optional)

try:
    # Get cluster events log. Returns an array of events.
    api_instance.v1_logs_get(stime=stime, etime=etime, order=order, limit=limit, offset=offset)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_logs_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Use module runtime configuration command (if defined) to configure new arguments for the module.
    api_instance.v1_modules_config_bdb_stringuid_post()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_modules_config_bdb_stringuid_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # List available modules, i.e. modules stored within the CCS Example request:
    api_instance.v1_modules_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_modules_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Uploads a new module into the CCS
    api_instance.v1_modules_post()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_modules_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The Module unique ID.

try:
    # Delete a Module.
    api_instance.v1_modules_stringuid_delete(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_modules_stringuid_delete: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get specific available modules, i.e. modules stored within the CCS Example request:
    api_instance.v1_modules_stringuid_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_modules_stringuid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Upgrades module version on specific BDB
    api_instance.v1_modules_upgrade_bdb_stringuid_post()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_modules_upgrade_bdb_stringuid_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get fs wd path config for a specific node.
    api_instance.v1_node_intnode_id_fs_wd_fs_path_config_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_node_intnode_id_fs_wd_fs_path_config_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Update fs wd path config for a specific node.
    api_instance.v1_node_intnode_id_fs_wd_fs_path_config_put()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_node_intnode_id_fs_wd_fs_path_config_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get the status of all currently executing, pending or completed actions on all nodes.
    api_instance.v1_nodes_actions_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_nodes_actions_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
ignore_settings = 'ignore_settings_example' # str | Optional retrieve updated alert state regardless if alert is enabled in cluster’s alert_settings. When not present a disabled alert will always be retrieved as disabled with a false state. (optional)

try:
    # Get all alert states for all nodes.
    api_instance.v1_nodes_alerts_get(ignore_settings=ignore_settings)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_nodes_alerts_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
ignore_settings = 'ignore_settings_example' # str | Optional retrieve updated alert state regardless if alert is enabled in cluster’s alert_settings. When not present a disabled alert will always be retrieved as disabled with a false state. (optional)

try:
    # Get node alert state.
    api_instance.v1_nodes_alerts_intuid_alert_get(ignore_settings=ignore_settings)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_nodes_alerts_intuid_alert_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
ignore_settings = 'ignore_settings_example' # str | Optional retrieve updated alert state regardless if alert is enabled in cluster’s alert_settings. When not present a disabled alert will always be retrieved as disabled with a false state. (optional)

try:
    # Get all alert states for a node.
    api_instance.v1_nodes_alerts_intuid_get(ignore_settings=ignore_settings)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_nodes_alerts_intuid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get all cluster nodes.
    api_instance.v1_nodes_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_nodes_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the node requested.

try:
    # Get single cluster node.
    api_instance.v1_nodes_intuid_get(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_nodes_intuid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the updated node.

try:
    # Update a node object.
    api_instance.v1_nodes_intuid_put(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_nodes_intuid_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
action = 'action_example' # str | The name of the action to cancel.

try:
    # Cancel a queued or executing node action, or remove the status of a previously executed and completed action.
    api_instance.v1_nodes_node_uid_actions_action_delete(action)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_nodes_node_uid_actions_action_delete: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    api_instance.v1_nodes_node_uid_actions_action_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_nodes_node_uid_actions_action_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
action = 'action_example' # str | The name of the action required. Currently supported actions are: remove : removes the node from the cluster after migrating all bound resources to other nodes. As soon as a successful remove request is received, the cluster will no longer automatically migrate resources (shards/endpoints) to the node, even if the remove task fails at some point. maintenance_on : creates a snapshot of the node, migrate shards to other nodes and makes sure it can undergo maintenance. If there aren’t enough resources to migrate shards out of the maintained node, set “keep_slave_shards”: true to keep the slave shards in place but demote any master shards. maintenance_off : restores node to the state it was before maintenance started. By default it uses the latest node snapshot. Using “snapshot_name”: “…” can be used to restore from a different snapshot. To avoid restoring shards at the node, use “skip_shards_restore”: true . enslave_node : enslave all bound resources.

try:
    # Initiate a node action.
    api_instance.v1_nodes_node_uid_actions_action_post(action)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_nodes_node_uid_actions_action_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
action = 'action_example' # str | The action to check.

try:
    # Get the status of a currently executing, queued or completed action, or all actions, on a specific node.
    api_instance.v1_nodes_node_uid_actions_get(action)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_nodes_node_uid_actions_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
interval = 'interval_example' # str | Optional time interval for which we want stats: 1sec/10sec/5min/15min/1hour/12hour/1week (optional)
stime = 'stime_example' # str | Optional start time from which we want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)
etime = 'etime_example' # str | Optional end time after which we don’t want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)

try:
    # Get stats for all nodes.
    api_instance.v1_nodes_stats_get(interval=interval, stime=stime, etime=etime)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_nodes_stats_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the node requested.
interval = 'interval_example' # str | Optional time interval for which we want stats: 1sec/10sec/5min/15min/1hour/12hour/1week (optional)
stime = 'stime_example' # str | Optional start time from which we want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)
etime = 'etime_example' # str | Optional end time after which we don’t want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)

try:
    # Get stats for node.
    api_instance.v1_nodes_stats_intuid_get(uid, interval=interval, stime=stime, etime=etime)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_nodes_stats_intuid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
interval = 'interval_example' # str | Optional time interval for which we want stats: 1sec/10sec/5min/15min/1hour/12hour/1week. Default: 1sec. (optional)
stime = 'stime_example' # str | Optional start time from which we want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)
etime = 'etime_example' # str | Optional end time after which we don’t want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)

try:
    # Get stats for all nodes.
    api_instance.v1_nodes_stats_last_get(interval=interval, stime=stime, etime=etime)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_nodes_stats_last_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the node requested.
interval = 'interval_example' # str | Optional time interval for which we want stats: 1sec/10sec/5min/15min/1hour/12hour/1week. Default: 1sec. (optional)
stime = 'stime_example' # str | Optional start time from which we want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)
etime = 'etime_example' # str | Optional end time after which we don’t want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)

try:
    # Get the last stats of a node.
    api_instance.v1_nodes_stats_last_intuid_get(uid, interval=interval, stime=stime, etime=etime)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_nodes_stats_last_intuid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get the OCSP configuration, as JSON.
    api_instance.v1_ocsp_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_ocsp_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Set or update cluster OCSP configuration.
    api_instance.v1_ocsp_put()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_ocsp_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get the OCSP status, as JSON.
    api_instance.v1_ocsp_status_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_ocsp_status_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Manually initiate a query to the OCSP server, and get the response as JSON. The staple is stored if the ocsp feature is enabled
    api_instance.v1_ocsp_test_post()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_ocsp_test_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get all redis_acl objects.
    api_instance.v1_redis_acls_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_redis_acls_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The redis_acl unique ID.

try:
    # Delete a redis_acl object.
    api_instance.v1_redis_acls_intuid_delete(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_redis_acls_intuid_delete: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The object’s unique ID.

try:
    # Get a single redis_acl object.
    api_instance.v1_redis_acls_intuid_get(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_redis_acls_intuid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Update an existing redis_acl object.
    api_instance.v1_redis_acls_intuid_put()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_redis_acls_intuid_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Create a new redis_acl object (a named redis acl)
    api_instance.v1_redis_acls_post()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_redis_acls_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get all role objects.
    api_instance.v1_roles_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_roles_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The role unique ID.

try:
    # Delete a role object.
    api_instance.v1_roles_intuid_delete(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_roles_intuid_delete: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The RLEC role unique ID.

try:
    # Get a single role object.
    api_instance.v1_roles_intuid_get(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_roles_intuid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Update an existing role object.
    api_instance.v1_roles_intuid_put()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_roles_intuid_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Create a new role.
    api_instance.v1_roles_post()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_roles_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
parent_uid = 'parent_uid_example' # str | Optional return only shard from the given BDB ID. (optional)
interval = 'interval_example' # str | Optional time interval for which we want stats: 1sec/10sec/5min/15min/1hour/12hour/1week (optional)
stime = 'stime_example' # str | Optional start time from which we want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)
etime = 'etime_example' # str | Optional end time after which we don’t want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)
metrics = 'metrics_example' # str | Optional comma separated list of metric names for which we want statistics (default is all). (optional)

try:
    # Get stats for all shards.
    api_instance.v1_shards_stats_get(parent_uid=parent_uid, interval=interval, stime=stime, etime=etime, metrics=metrics)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_shards_stats_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the shard requested.
interval = 'interval_example' # str | Optional time interval for which we want stats: 1sec/10sec/5min/15min/1hour/12hour/1week (optional)
stime = 'stime_example' # str | Optional start time from which we want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)
etime = 'etime_example' # str | Optional end time after which we don’t want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)

try:
    # Get stats for a specific shard.
    api_instance.v1_shards_stats_intuid_get(uid, interval=interval, stime=stime, etime=etime)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_shards_stats_intuid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
interval = 'interval_example' # str | Optional time interval for which we want stats: 1sec/10sec/5min/15min/1hour/12hour/1week. Default: 1sec. (optional)
stime = 'stime_example' # str | Optional start time from which we want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)
etime = 'etime_example' # str | Optional end time after which we don’t want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)

try:
    # Get last stats for all shards.
    api_instance.v1_shards_stats_last_get(interval=interval, stime=stime, etime=etime)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_shards_stats_last_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The unique ID of the shard requested.
interval = 'interval_example' # str | Optional time interval for which we want stats: 1sec/10sec/5min/15min/1hour/12hour/1week. Default: 1sec. (optional)
stime = 'stime_example' # str | Optional start time from which we want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)
etime = 'etime_example' # str | Optional end time after which we don’t want the stats. Should comply with the [ISO_8601](https://en.wikipedia.org/wiki/ISO_8601) format (optional)

try:
    # Get stats for a specific shard.
    api_instance.v1_shards_stats_last_intuid_get(uid, interval=interval, stime=stime, etime=etime)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_shards_stats_last_intuid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
name = 'name_example' # str | The unique Name of the suffix requested.

try:
    # Get single DNS suffix.
    api_instance.v1_suffix_stringname_get(name)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_suffix_stringname_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get all DNS suffixes in the cluster.
    api_instance.v1_suffixes_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_suffixes_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Authorize a RLEC user.
    api_instance.v1_users_authorize_post()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_users_authorize_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get all RLEC users.
    api_instance.v1_users_get()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_users_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The RLEC user unique ID.

try:
    # Delete a RLEC user.
    api_instance.v1_users_intuid_delete(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_users_intuid_delete: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The RLEC user unique ID.

try:
    # Get a single RLEC user.
    api_instance.v1_users_intuid_get(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_users_intuid_get: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))
uid = 'uid_example' # str | The RLEC user unique ID.

try:
    # Update a RLEC user configuration.
    api_instance.v1_users_intuid_put(uid)
except ApiException as e:
    print("Exception when calling DefaultApi->v1_users_intuid_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Delete a password from the list of an internal user’s passwords.
    api_instance.v1_users_password_delete()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_users_password_delete: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Add a new password to an internal user’s passwords list.
    api_instance.v1_users_password_post()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_users_password_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Reset the password list of an internal user to include a (single) new password.
    api_instance.v1_users_password_put()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_users_password_put: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Create a new RLEC user.
    api_instance.v1_users_post()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_users_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Get a new authentication token.
    api_instance.v1_users_refresh_jwt_post()
except ApiException as e:
    print("Exception when calling DefaultApi->v1_users_refresh_jwt_post: %s\n" % e)

# create an instance of the API class
api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(configuration))

try:
    # Create a new database in the cluster. See /v1/bdbs for more information. The database’s configuration should be under the “bdb” field.
    api_instance.v2_bdbs_post()
except ApiException as e:
    print("Exception when calling DefaultApi->v2_bdbs_post: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *//localhost:80/*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**v1_actions_action_uid_get**](docs/DefaultApi.md#v1_actions_action_uid_get) | **GET** /v1/actions/(action_uid) | 
*DefaultApi* | [**v1_actions_get**](docs/DefaultApi.md#v1_actions_get) | **GET** /v1/actions | Get the status of all currently executing, pending or completed actions on all entities (cluster, nodes and bdbs). This API is used to track every long-lived API request which returns either a task_id or an action_uid.
*DefaultApi* | [**v1_bdbs_alerts_get**](docs/DefaultApi.md#v1_bdbs_alerts_get) | **GET** /v1/bdbs/alerts | Get all alert states for all bdbs.
*DefaultApi* | [**v1_bdbs_alerts_intuid_alert_get**](docs/DefaultApi.md#v1_bdbs_alerts_intuid_alert_get) | **GET** /v1/bdbs/alerts/(int:uid)/(alert) | Get bdb alert state.
*DefaultApi* | [**v1_bdbs_alerts_intuid_get**](docs/DefaultApi.md#v1_bdbs_alerts_intuid_get) | **GET** /v1/bdbs/alerts/(int:uid) | Get all alert states for bdb.
*DefaultApi* | [**v1_bdbs_alerts_intuid_post**](docs/DefaultApi.md#v1_bdbs_alerts_intuid_post) | **POST** /v1/bdbs/alerts/(int:uid) | Updates database’s one or many alerts configuration
*DefaultApi* | [**v1_bdbs_bdb_uid_peer_stats_get**](docs/DefaultApi.md#v1_bdbs_bdb_uid_peer_stats_get) | **GET** /v1/bdbs/(bdb_uid)/peer_stats | Get stats for a all peer instances of a local CRDB instance.
*DefaultApi* | [**v1_bdbs_bdb_uid_peer_stats_intuid_get**](docs/DefaultApi.md#v1_bdbs_bdb_uid_peer_stats_intuid_get) | **GET** /v1/bdbs/(bdb_uid)/peer_stats/(int:uid) | Get stats for a specific CRDB peer instance.
*DefaultApi* | [**v1_bdbs_bdb_uid_sync_source_stats_get**](docs/DefaultApi.md#v1_bdbs_bdb_uid_sync_source_stats_get) | **GET** /v1/bdbs/(bdb_uid)/sync_source_stats | Get stats for a all syncer sources of a local database.
*DefaultApi* | [**v1_bdbs_bdb_uid_sync_source_stats_intuid_get**](docs/DefaultApi.md#v1_bdbs_bdb_uid_sync_source_stats_intuid_get) | **GET** /v1/bdbs/(bdb_uid)/sync_source_stats/(int:uid) | Get stats for a specific syncer (replica-of) instance.
*DefaultApi* | [**v1_bdbs_crdt_sources_alerts_get**](docs/DefaultApi.md#v1_bdbs_crdt_sources_alerts_get) | **GET** /v1/bdbs/crdt_sources/alerts | Get all alert states for all crdt sources of all CRDBs.
*DefaultApi* | [**v1_bdbs_crdt_sources_alerts_intuid_get**](docs/DefaultApi.md#v1_bdbs_crdt_sources_alerts_intuid_get) | **GET** /v1/bdbs/crdt_sources/alerts/(int:uid) | Get all alert states for all crdt source for specific local bdb of CRDB.
*DefaultApi* | [**v1_bdbs_crdt_sources_alerts_intuid_intcrdt_src_id_alert_get**](docs/DefaultApi.md#v1_bdbs_crdt_sources_alerts_intuid_intcrdt_src_id_alert_get) | **GET** /v1/bdbs/crdt_sources/alerts/(int:uid)/(int:crdt_src_id)/(alert) | Get bdb alert state.
*DefaultApi* | [**v1_bdbs_crdt_sources_alerts_intuid_intcrdt_src_id_get**](docs/DefaultApi.md#v1_bdbs_crdt_sources_alerts_intuid_intcrdt_src_id_get) | **GET** /v1/bdbs/crdt_sources/alerts/(int:uid)/(int:crdt_src_id) | Get all alert states for specific crdt source for specific local bdb of CRDB.
*DefaultApi* | [**v1_bdbs_get**](docs/DefaultApi.md#v1_bdbs_get) | **GET** /v1/bdbs | Get all databases in the cluster.
*DefaultApi* | [**v1_bdbs_intuid_actions_backup_reset_status_put**](docs/DefaultApi.md#v1_bdbs_intuid_actions_backup_reset_status_put) | **PUT** /v1/bdbs/(int:uid)/actions/backup_reset_status | Reset database current backup status (backup_status) to idle if not in progress. As well clear exiting backup_failure_reason if exits
*DefaultApi* | [**v1_bdbs_intuid_actions_export_post**](docs/DefaultApi.md#v1_bdbs_intuid_actions_export_post) | **POST** /v1/bdbs/(int:uid)/actions/export | Initiate a database export.
*DefaultApi* | [**v1_bdbs_intuid_actions_export_reset_status_put**](docs/DefaultApi.md#v1_bdbs_intuid_actions_export_reset_status_put) | **PUT** /v1/bdbs/(int:uid)/actions/export_reset_status | Reset database current export status (export_status) to idle if not in progress. As well clear exiting export_failure_reason if exits
*DefaultApi* | [**v1_bdbs_intuid_actions_import_post**](docs/DefaultApi.md#v1_bdbs_intuid_actions_import_post) | **POST** /v1/bdbs/(int:uid)/actions/import | Initiate a manual import process.
*DefaultApi* | [**v1_bdbs_intuid_actions_import_reset_status_put**](docs/DefaultApi.md#v1_bdbs_intuid_actions_import_reset_status_put) | **PUT** /v1/bdbs/(int:uid)/actions/import_reset_status | Reset database current import status (import_status) to idle if not in progress. As well clear exiting import_failure_reason if exits
*DefaultApi* | [**v1_bdbs_intuid_actions_optimize_shards_placement_get**](docs/DefaultApi.md#v1_bdbs_intuid_actions_optimize_shards_placement_get) | **GET** /v1/bdbs/(int:uid)/actions/optimize_shards_placement | Get optimized shards placement for the given database.
*DefaultApi* | [**v1_bdbs_intuid_actions_recover_get**](docs/DefaultApi.md#v1_bdbs_intuid_actions_recover_get) | **GET** /v1/bdbs/(int:uid)/actions/recover | Fetch the recovery plan for a database. The recovery plan provides information about the recovery status (if it is possible) and specific detail on which available files to recovery from have been found.
*DefaultApi* | [**v1_bdbs_intuid_actions_recover_post**](docs/DefaultApi.md#v1_bdbs_intuid_actions_recover_post) | **POST** /v1/bdbs/(int:uid)/actions/recover | Initiate recovery for a database in recovery state.
*DefaultApi* | [**v1_bdbs_intuid_anyaction_put**](docs/DefaultApi.md#v1_bdbs_intuid_anyaction_put) | **PUT** /v1/bdbs/(int:uid)/(any:action) | Update the configuration of an active database.
*DefaultApi* | [**v1_bdbs_intuid_command_post**](docs/DefaultApi.md#v1_bdbs_intuid_command_post) | **POST** /v1/bdbs/(int:uid)/command | Execute a redis/memcached command, per the db type.
*DefaultApi* | [**v1_bdbs_intuid_delete**](docs/DefaultApi.md#v1_bdbs_intuid_delete) | **DELETE** /v1/bdbs/(int:uid) | Delete an active database.
*DefaultApi* | [**v1_bdbs_intuid_get**](docs/DefaultApi.md#v1_bdbs_intuid_get) | **GET** /v1/bdbs/(int:uid) | Get single database (bdb object) as json.
*DefaultApi* | [**v1_bdbs_intuid_passwords_delete**](docs/DefaultApi.md#v1_bdbs_intuid_passwords_delete) | **DELETE** /v1/bdbs/(int:uid)/passwords | Delete a password from the bdb’s default user (i.e., for AUTH &lt;password&gt; authentications).
*DefaultApi* | [**v1_bdbs_intuid_passwords_post**](docs/DefaultApi.md#v1_bdbs_intuid_passwords_post) | **POST** /v1/bdbs/(int:uid)/passwords | Add a password to the bdb’s default user (i.e., for AUTH &lt;password&gt; authentications).
*DefaultApi* | [**v1_bdbs_intuid_passwords_put**](docs/DefaultApi.md#v1_bdbs_intuid_passwords_put) | **PUT** /v1/bdbs/(int:uid)/passwords | Set a (single) password to the bdb’s default user (i.e., for AUTH &lt;password&gt; authentications).
*DefaultApi* | [**v1_bdbs_intuid_put**](docs/DefaultApi.md#v1_bdbs_intuid_put) | **PUT** /v1/bdbs/(int:uid) | Update the configuration of an active database.  This is the simplified version of the update request which contains no additional action.
*DefaultApi* | [**v1_bdbs_intuid_upgrade_post**](docs/DefaultApi.md#v1_bdbs_intuid_upgrade_post) | **POST** /v1/bdbs/(int:uid)/upgrade | Upgrade a BDB
*DefaultApi* | [**v1_bdbs_post**](docs/DefaultApi.md#v1_bdbs_post) | **POST** /v1/bdbs | Create a new database in the cluster.
*DefaultApi* | [**v1_bdbs_replica_sources_alerts_get**](docs/DefaultApi.md#v1_bdbs_replica_sources_alerts_get) | **GET** /v1/bdbs/replica_sources/alerts | Get all alert states for all replica sources of all BDBs.
*DefaultApi* | [**v1_bdbs_replica_sources_alerts_intuid_get**](docs/DefaultApi.md#v1_bdbs_replica_sources_alerts_intuid_get) | **GET** /v1/bdbs/replica_sources/alerts/(int:uid) | Get all alert states for all replica source of specific bdb.
*DefaultApi* | [**v1_bdbs_replica_sources_alerts_intuid_intreplica_src_id_alert_get**](docs/DefaultApi.md#v1_bdbs_replica_sources_alerts_intuid_intreplica_src_id_alert_get) | **GET** /v1/bdbs/replica_sources/alerts/(int:uid)/(int:replica_src_id)/(alert) | Get replica source alert state of specific bdb.
*DefaultApi* | [**v1_bdbs_replica_sources_alerts_intuid_intreplica_src_id_get**](docs/DefaultApi.md#v1_bdbs_replica_sources_alerts_intuid_intreplica_src_id_get) | **GET** /v1/bdbs/replica_sources/alerts/(int:uid)/(int:replica_src_id) | Get all alert states for specific replica source of bdb.
*DefaultApi* | [**v1_bdbs_stats_get**](docs/DefaultApi.md#v1_bdbs_stats_get) | **GET** /v1/bdbs/stats | Get stats for all BDBs.
*DefaultApi* | [**v1_bdbs_stats_intuid_get**](docs/DefaultApi.md#v1_bdbs_stats_intuid_get) | **GET** /v1/bdbs/stats/(int:uid) | Get stats for BDB.
*DefaultApi* | [**v1_bdbs_stats_last_get**](docs/DefaultApi.md#v1_bdbs_stats_last_get) | **GET** /v1/bdbs/stats/last | Get the most recent statistic information for all BDBs.
*DefaultApi* | [**v1_bdbs_stats_last_intuid_get**](docs/DefaultApi.md#v1_bdbs_stats_last_intuid_get) | **GET** /v1/bdbs/stats/last/(int:uid) | Get the most recent statistic information for BDB.
*DefaultApi* | [**v1_bdbs_stringuid_modules_config_post**](docs/DefaultApi.md#v1_bdbs_stringuid_modules_config_post) | **POST** /v1/bdbs/(string:uid)/modules/config | 
*DefaultApi* | [**v1_bdbs_stringuid_modules_upgrade_post**](docs/DefaultApi.md#v1_bdbs_stringuid_modules_upgrade_post) | **POST** /v1/bdbs/(string:uid)/modules/upgrade | 
*DefaultApi* | [**v1_bootstrap_action_post**](docs/DefaultApi.md#v1_bootstrap_action_post) | **POST** /v1/bootstrap/(action) | Initiate bootstrapping.
*DefaultApi* | [**v1_bootstrap_get**](docs/DefaultApi.md#v1_bootstrap_get) | **GET** /v1/bootstrap | Get the local node’s bootstrap status.
*DefaultApi* | [**v1_bootstrap_validate_action_post**](docs/DefaultApi.md#v1_bootstrap_validate_action_post) | **POST** /v1/bootstrap/validate/(action) | Perform bootstrap validation.
*DefaultApi* | [**v1_cluster_actions_action_delete**](docs/DefaultApi.md#v1_cluster_actions_action_delete) | **DELETE** /v1/cluster/actions/(action) | Cancel a queued or executing cluster action, or remove the status of a previously executed and completed action.
*DefaultApi* | [**v1_cluster_actions_action_get**](docs/DefaultApi.md#v1_cluster_actions_action_get) | **GET** /v1/cluster/actions/(action) | 
*DefaultApi* | [**v1_cluster_actions_action_post**](docs/DefaultApi.md#v1_cluster_actions_action_post) | **POST** /v1/cluster/actions/(action) | Initiate a cluster-wide action.
*DefaultApi* | [**v1_cluster_actions_get**](docs/DefaultApi.md#v1_cluster_actions_get) | **GET** /v1/cluster/actions | Get the status of a currently executing, queued or completed cluster action.
*DefaultApi* | [**v1_cluster_alerts_alert_get**](docs/DefaultApi.md#v1_cluster_alerts_alert_get) | **GET** /v1/cluster/alerts/(alert) | Get cluster alert state.
*DefaultApi* | [**v1_cluster_alerts_get**](docs/DefaultApi.md#v1_cluster_alerts_get) | **GET** /v1/cluster/alerts | Get all alert states for the cluster object.
*DefaultApi* | [**v1_cluster_auditing_db_conns_delete**](docs/DefaultApi.md#v1_cluster_auditing_db_conns_delete) | **DELETE** /v1/cluster/auditing/db_conns | Delete the Database Connections Auditing configurations.
*DefaultApi* | [**v1_cluster_auditing_db_conns_get**](docs/DefaultApi.md#v1_cluster_auditing_db_conns_get) | **GET** /v1/cluster/auditing/db_conns | Get the Database Connections Auditing configuration, as JSON.
*DefaultApi* | [**v1_cluster_auditing_db_conns_put**](docs/DefaultApi.md#v1_cluster_auditing_db_conns_put) | **PUT** /v1/cluster/auditing/db_conns | Update the Database Connections Auditing configurations.
*DefaultApi* | [**v1_cluster_certificates_get**](docs/DefaultApi.md#v1_cluster_certificates_get) | **GET** /v1/cluster/certificates | Get the clusters certificates.
*DefaultApi* | [**v1_cluster_certificates_rotate_post**](docs/DefaultApi.md#v1_cluster_certificates_rotate_post) | **POST** /v1/cluster/certificates/rotate | Regenerates all internal cluster certificates. the certificate rotation will be performed on all nodes within the cluster. If “name” is provided, rotate only the specified certificate on all nodes within the cluster.
*DefaultApi* | [**v1_cluster_certificates_stringcertificate_name_delete**](docs/DefaultApi.md#v1_cluster_certificates_stringcertificate_name_delete) | **DELETE** /v1/cluster/certificates/(string:certificate_name) | Removes specified cluster certificate both from CCS and from disk across all nodes. Only optional certificates can be deleted through this endpoint.
*DefaultApi* | [**v1_cluster_fs_wd_config_get**](docs/DefaultApi.md#v1_cluster_fs_wd_config_get) | **GET** /v1/cluster/fs_wd/config | Get cluster-wide fs wd config.
*DefaultApi* | [**v1_cluster_fs_wd_config_put**](docs/DefaultApi.md#v1_cluster_fs_wd_config_put) | **PUT** /v1/cluster/fs_wd/config | Set cluster-wide fs wd config.
*DefaultApi* | [**v1_cluster_fs_wd_fs_path_config_get**](docs/DefaultApi.md#v1_cluster_fs_wd_fs_path_config_get) | **GET** /v1/cluster/fs_wd/(fs_path)/config | Get fs wd path config for cluster.
*DefaultApi* | [**v1_cluster_fs_wd_fs_path_config_put**](docs/DefaultApi.md#v1_cluster_fs_wd_fs_path_config_put) | **PUT** /v1/cluster/fs_wd/(fs_path)/config | Set fs wd path config for cluster.
*DefaultApi* | [**v1_cluster_get**](docs/DefaultApi.md#v1_cluster_get) | **GET** /v1/cluster | Get cluster info.
*DefaultApi* | [**v1_cluster_ldap_delete**](docs/DefaultApi.md#v1_cluster_ldap_delete) | **DELETE** /v1/cluster/ldap | Clear the LDAP configuration.
*DefaultApi* | [**v1_cluster_ldap_get**](docs/DefaultApi.md#v1_cluster_ldap_get) | **GET** /v1/cluster/ldap | Get the LDAP configuration, as JSON.
*DefaultApi* | [**v1_cluster_ldap_put**](docs/DefaultApi.md#v1_cluster_ldap_put) | **PUT** /v1/cluster/ldap | Set or update cluster LDAP configuration.
*DefaultApi* | [**v1_cluster_module_capabilities_get**](docs/DefaultApi.md#v1_cluster_module_capabilities_get) | **GET** /v1/cluster/module-capabilities | List possible redis module capabilities Example request:
*DefaultApi* | [**v1_cluster_put**](docs/DefaultApi.md#v1_cluster_put) | **PUT** /v1/cluster | Update cluster settings.
*DefaultApi* | [**v1_cluster_services_configuration_get**](docs/DefaultApi.md#v1_cluster_services_configuration_get) | **GET** /v1/cluster/services_configuration | Get cluster services settings.
*DefaultApi* | [**v1_cluster_services_configuration_put**](docs/DefaultApi.md#v1_cluster_services_configuration_put) | **PUT** /v1/cluster/services_configuration | Update the cluster services settings.
*DefaultApi* | [**v1_cluster_stats_get**](docs/DefaultApi.md#v1_cluster_stats_get) | **GET** /v1/cluster/stats | Get cluster stats.
*DefaultApi* | [**v1_cluster_stats_last_get**](docs/DefaultApi.md#v1_cluster_stats_last_get) | **GET** /v1/cluster/stats/last | Get the last cluster stat.
*DefaultApi* | [**v1_cluster_update_cert_put**](docs/DefaultApi.md#v1_cluster_update_cert_put) | **PUT** /v1/cluster/update_cert | Replaces specified cluster certificate with given one, the new certificate will be replaced on all nodes within the cluster. This end point will make sure given certificate is valid before actually updating the cluster.
*DefaultApi* | [**v1_debuginfo_all_bdb_intbdb_uid_get**](docs/DefaultApi.md#v1_debuginfo_all_bdb_intbdb_uid_get) | **GET** /v1/debuginfo/all/bdb/(int:bdb_uid) | Fetch debuginfo from all nodes that are relevent to given bdb uid.
*DefaultApi* | [**v1_debuginfo_all_get**](docs/DefaultApi.md#v1_debuginfo_all_get) | **GET** /v1/debuginfo/all | Fetch debuginfo from all nodes.
*DefaultApi* | [**v1_debuginfo_node_bdb_intbdb_uid_get**](docs/DefaultApi.md#v1_debuginfo_node_bdb_intbdb_uid_get) | **GET** /v1/debuginfo/node/bdb/(int:bdb_uid) | Fetch debuginfo tarfile which contains logs and other system information used for troubleshooting, for the given bdb.
*DefaultApi* | [**v1_debuginfo_node_get**](docs/DefaultApi.md#v1_debuginfo_node_get) | **GET** /v1/debuginfo/node | Fetch debuginfo tarfile which contains logs and other system information used for troubleshooting.
*DefaultApi* | [**v1_endpoints_stats_get**](docs/DefaultApi.md#v1_endpoints_stats_get) | **GET** /v1/endpoints/stats | Get stats for all endpoint-proxy links. Note: this method will return both endpoints and listeners stats for backwards compatability.
*DefaultApi* | [**v1_jsonschema_get**](docs/DefaultApi.md#v1_jsonschema_get) | **GET** /v1/jsonschema | Get the jsonschema of RLEC objects.
*DefaultApi* | [**v1_ldap_mappings_get**](docs/DefaultApi.md#v1_ldap_mappings_get) | **GET** /v1/ldap_mappings | Get all ldap_mapping objects.
*DefaultApi* | [**v1_ldap_mappings_intuid_delete**](docs/DefaultApi.md#v1_ldap_mappings_intuid_delete) | **DELETE** /v1/ldap_mappings/(int:uid) | Delete an LDAP mapping object.
*DefaultApi* | [**v1_ldap_mappings_intuid_get**](docs/DefaultApi.md#v1_ldap_mappings_intuid_get) | **GET** /v1/ldap_mappings/(int:uid) | Get a single ldap_mapping object.
*DefaultApi* | [**v1_ldap_mappings_intuid_put**](docs/DefaultApi.md#v1_ldap_mappings_intuid_put) | **PUT** /v1/ldap_mappings/(int:uid) | Update an existing ldap_mapping object.
*DefaultApi* | [**v1_ldap_mappings_post**](docs/DefaultApi.md#v1_ldap_mappings_post) | **POST** /v1/ldap_mappings | Create a new LDAP mapping.
*DefaultApi* | [**v1_license_get**](docs/DefaultApi.md#v1_license_get) | **GET** /v1/license | Returns the license details, including license string, expiration, and supported features.
*DefaultApi* | [**v1_license_put**](docs/DefaultApi.md#v1_license_put) | **PUT** /v1/license | Install a new license string.
*DefaultApi* | [**v1_logs_get**](docs/DefaultApi.md#v1_logs_get) | **GET** /v1/logs | Get cluster events log. Returns an array of events.
*DefaultApi* | [**v1_modules_config_bdb_stringuid_post**](docs/DefaultApi.md#v1_modules_config_bdb_stringuid_post) | **POST** /v1/modules/config/bdb/(string:uid) | Use module runtime configuration command (if defined) to configure new arguments for the module.
*DefaultApi* | [**v1_modules_get**](docs/DefaultApi.md#v1_modules_get) | **GET** /v1/modules | List available modules, i.e. modules stored within the CCS Example request:
*DefaultApi* | [**v1_modules_post**](docs/DefaultApi.md#v1_modules_post) | **POST** /v1/modules | Uploads a new module into the CCS
*DefaultApi* | [**v1_modules_stringuid_delete**](docs/DefaultApi.md#v1_modules_stringuid_delete) | **DELETE** /v1/modules/(string:uid) | Delete a Module.
*DefaultApi* | [**v1_modules_stringuid_get**](docs/DefaultApi.md#v1_modules_stringuid_get) | **GET** /v1/modules/(string:uid) | Get specific available modules, i.e. modules stored within the CCS Example request:
*DefaultApi* | [**v1_modules_upgrade_bdb_stringuid_post**](docs/DefaultApi.md#v1_modules_upgrade_bdb_stringuid_post) | **POST** /v1/modules/upgrade/bdb/(string:uid) | Upgrades module version on specific BDB
*DefaultApi* | [**v1_node_intnode_id_fs_wd_fs_path_config_get**](docs/DefaultApi.md#v1_node_intnode_id_fs_wd_fs_path_config_get) | **GET** /v1/node/(int:node_id)/fs_wd/(fs_path)/config | Get fs wd path config for a specific node.
*DefaultApi* | [**v1_node_intnode_id_fs_wd_fs_path_config_put**](docs/DefaultApi.md#v1_node_intnode_id_fs_wd_fs_path_config_put) | **PUT** /v1/node/(int:node_id)/fs_wd/(fs_path)/config | Update fs wd path config for a specific node.
*DefaultApi* | [**v1_nodes_actions_get**](docs/DefaultApi.md#v1_nodes_actions_get) | **GET** /v1/nodes/actions | Get the status of all currently executing, pending or completed actions on all nodes.
*DefaultApi* | [**v1_nodes_alerts_get**](docs/DefaultApi.md#v1_nodes_alerts_get) | **GET** /v1/nodes/alerts | Get all alert states for all nodes.
*DefaultApi* | [**v1_nodes_alerts_intuid_alert_get**](docs/DefaultApi.md#v1_nodes_alerts_intuid_alert_get) | **GET** /v1/nodes/alerts/(int:uid)/(alert) | Get node alert state.
*DefaultApi* | [**v1_nodes_alerts_intuid_get**](docs/DefaultApi.md#v1_nodes_alerts_intuid_get) | **GET** /v1/nodes/alerts/(int:uid) | Get all alert states for a node.
*DefaultApi* | [**v1_nodes_get**](docs/DefaultApi.md#v1_nodes_get) | **GET** /v1/nodes | Get all cluster nodes.
*DefaultApi* | [**v1_nodes_intuid_get**](docs/DefaultApi.md#v1_nodes_intuid_get) | **GET** /v1/nodes/(int:uid) | Get single cluster node.
*DefaultApi* | [**v1_nodes_intuid_put**](docs/DefaultApi.md#v1_nodes_intuid_put) | **PUT** /v1/nodes/(int:uid) | Update a node object.
*DefaultApi* | [**v1_nodes_node_uid_actions_action_delete**](docs/DefaultApi.md#v1_nodes_node_uid_actions_action_delete) | **DELETE** /v1/nodes/(node_uid)/actions/(action) | Cancel a queued or executing node action, or remove the status of a previously executed and completed action.
*DefaultApi* | [**v1_nodes_node_uid_actions_action_get**](docs/DefaultApi.md#v1_nodes_node_uid_actions_action_get) | **GET** /v1/nodes/(node_uid)/actions/(action) | 
*DefaultApi* | [**v1_nodes_node_uid_actions_action_post**](docs/DefaultApi.md#v1_nodes_node_uid_actions_action_post) | **POST** /v1/nodes/(node_uid)/actions/(action) | Initiate a node action.
*DefaultApi* | [**v1_nodes_node_uid_actions_get**](docs/DefaultApi.md#v1_nodes_node_uid_actions_get) | **GET** /v1/nodes/(node_uid)/actions | Get the status of a currently executing, queued or completed action, or all actions, on a specific node.
*DefaultApi* | [**v1_nodes_stats_get**](docs/DefaultApi.md#v1_nodes_stats_get) | **GET** /v1/nodes/stats | Get stats for all nodes.
*DefaultApi* | [**v1_nodes_stats_intuid_get**](docs/DefaultApi.md#v1_nodes_stats_intuid_get) | **GET** /v1/nodes/stats/(int:uid) | Get stats for node.
*DefaultApi* | [**v1_nodes_stats_last_get**](docs/DefaultApi.md#v1_nodes_stats_last_get) | **GET** /v1/nodes/stats/last | Get stats for all nodes.
*DefaultApi* | [**v1_nodes_stats_last_intuid_get**](docs/DefaultApi.md#v1_nodes_stats_last_intuid_get) | **GET** /v1/nodes/stats/last/(int:uid) | Get the last stats of a node.
*DefaultApi* | [**v1_ocsp_get**](docs/DefaultApi.md#v1_ocsp_get) | **GET** /v1/ocsp | Get the OCSP configuration, as JSON.
*DefaultApi* | [**v1_ocsp_put**](docs/DefaultApi.md#v1_ocsp_put) | **PUT** /v1/ocsp | Set or update cluster OCSP configuration.
*DefaultApi* | [**v1_ocsp_status_get**](docs/DefaultApi.md#v1_ocsp_status_get) | **GET** /v1/ocsp/status | Get the OCSP status, as JSON.
*DefaultApi* | [**v1_ocsp_test_post**](docs/DefaultApi.md#v1_ocsp_test_post) | **POST** /v1/ocsp/test | Manually initiate a query to the OCSP server, and get the response as JSON. The staple is stored if the ocsp feature is enabled
*DefaultApi* | [**v1_redis_acls_get**](docs/DefaultApi.md#v1_redis_acls_get) | **GET** /v1/redis_acls | Get all redis_acl objects.
*DefaultApi* | [**v1_redis_acls_intuid_delete**](docs/DefaultApi.md#v1_redis_acls_intuid_delete) | **DELETE** /v1/redis_acls/(int:uid) | Delete a redis_acl object.
*DefaultApi* | [**v1_redis_acls_intuid_get**](docs/DefaultApi.md#v1_redis_acls_intuid_get) | **GET** /v1/redis_acls/(int:uid) | Get a single redis_acl object.
*DefaultApi* | [**v1_redis_acls_intuid_put**](docs/DefaultApi.md#v1_redis_acls_intuid_put) | **PUT** /v1/redis_acls/(int:uid) | Update an existing redis_acl object.
*DefaultApi* | [**v1_redis_acls_post**](docs/DefaultApi.md#v1_redis_acls_post) | **POST** /v1/redis_acls | Create a new redis_acl object (a named redis acl)
*DefaultApi* | [**v1_roles_get**](docs/DefaultApi.md#v1_roles_get) | **GET** /v1/roles | Get all role objects.
*DefaultApi* | [**v1_roles_intuid_delete**](docs/DefaultApi.md#v1_roles_intuid_delete) | **DELETE** /v1/roles/(int:uid) | Delete a role object.
*DefaultApi* | [**v1_roles_intuid_get**](docs/DefaultApi.md#v1_roles_intuid_get) | **GET** /v1/roles/(int:uid) | Get a single role object.
*DefaultApi* | [**v1_roles_intuid_put**](docs/DefaultApi.md#v1_roles_intuid_put) | **PUT** /v1/roles/(int:uid) | Update an existing role object.
*DefaultApi* | [**v1_roles_post**](docs/DefaultApi.md#v1_roles_post) | **POST** /v1/roles | Create a new role.
*DefaultApi* | [**v1_shards_stats_get**](docs/DefaultApi.md#v1_shards_stats_get) | **GET** /v1/shards/stats | Get stats for all shards.
*DefaultApi* | [**v1_shards_stats_intuid_get**](docs/DefaultApi.md#v1_shards_stats_intuid_get) | **GET** /v1/shards/stats/(int:uid) | Get stats for a specific shard.
*DefaultApi* | [**v1_shards_stats_last_get**](docs/DefaultApi.md#v1_shards_stats_last_get) | **GET** /v1/shards/stats/last | Get last stats for all shards.
*DefaultApi* | [**v1_shards_stats_last_intuid_get**](docs/DefaultApi.md#v1_shards_stats_last_intuid_get) | **GET** /v1/shards/stats/last/(int:uid) | Get stats for a specific shard.
*DefaultApi* | [**v1_suffix_stringname_get**](docs/DefaultApi.md#v1_suffix_stringname_get) | **GET** /v1/suffix/(string:name) | Get single DNS suffix.
*DefaultApi* | [**v1_suffixes_get**](docs/DefaultApi.md#v1_suffixes_get) | **GET** /v1/suffixes | Get all DNS suffixes in the cluster.
*DefaultApi* | [**v1_users_authorize_post**](docs/DefaultApi.md#v1_users_authorize_post) | **POST** /v1/users/authorize | Authorize a RLEC user.
*DefaultApi* | [**v1_users_get**](docs/DefaultApi.md#v1_users_get) | **GET** /v1/users | Get all RLEC users.
*DefaultApi* | [**v1_users_intuid_delete**](docs/DefaultApi.md#v1_users_intuid_delete) | **DELETE** /v1/users/(int:uid) | Delete a RLEC user.
*DefaultApi* | [**v1_users_intuid_get**](docs/DefaultApi.md#v1_users_intuid_get) | **GET** /v1/users/(int:uid) | Get a single RLEC user.
*DefaultApi* | [**v1_users_intuid_put**](docs/DefaultApi.md#v1_users_intuid_put) | **PUT** /v1/users/(int:uid) | Update a RLEC user configuration.
*DefaultApi* | [**v1_users_password_delete**](docs/DefaultApi.md#v1_users_password_delete) | **DELETE** /v1/users/password | Delete a password from the list of an internal user’s passwords.
*DefaultApi* | [**v1_users_password_post**](docs/DefaultApi.md#v1_users_password_post) | **POST** /v1/users/password | Add a new password to an internal user’s passwords list.
*DefaultApi* | [**v1_users_password_put**](docs/DefaultApi.md#v1_users_password_put) | **PUT** /v1/users/password | Reset the password list of an internal user to include a (single) new password.
*DefaultApi* | [**v1_users_post**](docs/DefaultApi.md#v1_users_post) | **POST** /v1/users | Create a new RLEC user.
*DefaultApi* | [**v1_users_refresh_jwt_post**](docs/DefaultApi.md#v1_users_refresh_jwt_post) | **POST** /v1/users/refresh_jwt | Get a new authentication token.
*DefaultApi* | [**v2_bdbs_post**](docs/DefaultApi.md#v2_bdbs_post) | **POST** /v2/bdbs | Create a new database in the cluster. See /v1/bdbs for more information. The database’s configuration should be under the “bdb” field.

## Documentation For Models


## Documentation For Authorization

 All endpoints do not require authorization.


## Author


